# Super SLURPy: Python version of Speech and Language Ultrasound Research Package

This project is a Python port of [SLURP](https://github.com/cathylaporte/SLURP). 

## Installing

- Install the package manager uv: 
  - MacOS/Linux run `curl -LsSf https://astral.sh/uv/install.sh | sh`
  - Windows run `powershell -ExecutionPolicy ByPass -c "irm https://astral.sh/uv/install.ps1 | iex"`
  - See [uv](https://docs.astral.sh/uv/#getting-started) for more details.
- On the commandline run `uv tool install super_slurpy`
- Run `slurpy --help` for instructions.
- The package is called `super_slurpy` but the program itself is called just
  `slurpy` for convenience.

## Documentation

[Documentation](https://giuthas.github.io/slurpy/)

## Current version and development plans

See [Changelog](https://giuthas.github.io/slurpy/Changelog), for what's new in
the current version and what's coming up.

## Versioning

We use [SemVer](http://semver.org/) for versioning under the rules set out by
[PEP 440](https://www.python.org/dev/peps/pep-0440/) with the additional
understanding that releases before 1.0 (i.e. current releases at time of
writing) have not been tested in any way.

For the versions available, see the [tags on this
repository](https://github.com/giuthas/patkit/tags).

# Contributors

List of [contributors](https://giuthas.github.io/patkit/Contributors)

## Copyright and License

BSD-2-Clause license like original SLURP